@@ -1,6 +1,7 @@
 import os, sys
 import re
 from collections import OrderedDict
+from datetime import datetime
 try:
     curr_path = os.path.dirname(os.path.abspath(__file__))
     teedoc_project_path = os.path.abspath(os.path.join(curr_path, "..", "..", ".."))
@@ -93,12 +94,33 @@ class Plugin(Plugin_Base):
                         desc = metadata["desc"]
                     else:
                         desc = ""
+                    date = None
+                    ts = int(os.stat(file).st_mtime)
+                    if "date" in metadata:
+                        date = metadata["date"].strip().lower()
+                        # set date to false to disable date display
+                        if date and (date == "false" or date == "none"):
+                            date = ""
+                        else:
+                            GMT_FORMAT = '%Y-%m-%d'
+                            try:
+                                date_obj = datetime.strptime(date, GMT_FORMAT)
+                                ts = int(date_obj.timestamp())
+                            except Exception as e:
+                                pass
+                    if "author" in metadata:
+                        author = metadata["author"]
+                    else:
+                        author = ""
                     result["htmls"][file] = {
                         "title": title,
                         "desc": desc,
                         "keywords": keywords,
                         "tags": tags,
                         "body": html,
+                        "date": date,
+                        "ts": ts,
+                        "author": author,
                         # "toc": html.toc_html if html.toc_html else "",
                         "toc": "", # just empty, toc generated by js but not python
                         "metadata": metadata,
